==> dtkdeclarative_5.7.14.tar.xz: BUILD/src/translations/dtkdeclarative_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>AboutAction</name>
    <message>
        <location filename="../qml/AboutAction.qml" line="9"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../qml/AboutDialog.qml" line="80"/>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <location filename="../qml/AboutDialog.qml" line="94"/>
        <source>Homepage</source>
        <translation>Strona główna</translation>
    </message>
    <message>
        <location filename="../qml/AboutDialog.qml" line="109"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
</context>
<context>
    <name>HelpAction</name>
    <message>
        <location filename="../qml/HelpAction.qml" line="10"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
</context>
<context>
    <name>QuitAction</name>
    <message>
        <location filename="../qml/QuitAction.qml" line="9"/>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
</context>
<context>
    <name>SearchEdit</name>
    <message>
        <location filename="../qml/SearchEdit.qml" line="41"/>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../qml/settings/SettingsDialog.qml" line="79"/>
        <source>Restore Defaults</source>
        <translation>Przywróć domyślne</translation>
    </message>
</context>
<context>
    <name>ThemeMenu</name>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="11"/>
        <source>Theme</source>
        <translation>Motyw</translation>
    </message>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="23"/>
        <source>Light Theme</source>
        <translation>Jasny</translation>
    </message>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="29"/>
        <source>Dark Theme</source>
        <translation>Ciemny</translation>
    </message>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="35"/>
        <source>System Theme</source>
        <translation>Systemowy</translation>
    </message>
</context>
</TS>

==> dtkdeclarative_5.7.24.3.tar.xz: BUILD/src/translations/dtkdeclarative_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>AboutAction</name>
    <message>
        <location filename="../qml/AboutAction.qml" line="9"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../qml/AboutDialog.qml" line="83"/>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <location filename="../qml/AboutDialog.qml" line="97"/>
        <source>Homepage</source>
        <translation>Strona główna</translation>
    </message>
    <message>
        <location filename="../qml/AboutDialog.qml" line="112"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
</context>
<context>
    <name>HelpAction</name>
    <message>
        <location filename="../qml/HelpAction.qml" line="10"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
</context>
<context>
    <name>QuitAction</name>
    <message>
        <location filename="../qml/QuitAction.qml" line="9"/>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
</context>
<context>
    <name>SearchEdit</name>
    <message>
        <location filename="../qml/SearchEdit.qml" line="41"/>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../qml/settings/SettingsDialog.qml" line="79"/>
        <source>Restore Defaults</source>
        <translation>Przywróć domyślne</translation>
    </message>
</context>
<context>
    <name>TextField</name>
    <message>
        <location filename="../qml/TextField.qml" line="71"/>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="78"/>
        <source>Cut</source>
        <translation>Wytnij</translation>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="85"/>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="91"/>
        <source>Select All</source>
        <translation>Zaznacz wszystko</translation>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="98"/>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="105"/>
        <source>Redo</source>
        <translation>Ponów</translation>
    </message>
</context>
<context>
    <name>ThemeMenu</name>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="11"/>
        <source>Theme</source>
        <translation>Motyw</translation>
    </message>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="23"/>
        <source>Light Theme</source>
        <translation>Jasny</translation>
    </message>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="29"/>
        <source>Dark Theme</source>
        <translation>Ciemny</translation>
    </message>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="35"/>
        <source>System Theme</source>
        <translation>Systemowy</translation>
    </message>
</context>
</TS>
